@@ -139,7 +139,7 @@ func machinesNodeRoles(ctx context.Context, machines []*api.Machine) (leader *ap
 }
 
 func nomadNodeRoles(ctx context.Context, allocs []*api.AllocationStatus) (leader *api.AllocationStatus, replicas []*api.AllocationStatus, err error) {
-	var dialer = agent.DialerFromContext(ctx)
+	dialer := agent.DialerFromContext(ctx)
 
 	for _, alloc := range allocs {
 		pgclient := flypg.NewFromInstance(alloc.PrivateIP, dialer)
@@ -162,6 +162,22 @@ func nomadNodeRoles(ctx context.Context, allocs []*api.AllocationStatus) (leader
 	return leader, replicas, nil
 }
 
+func leaderIpFromNomadInstances(ctx context.Context, addrs []string) (string, error) {
+	dialer := agent.DialerFromContext(ctx)
+	for _, addr := range addrs {
+		pgclient := flypg.NewFromInstance(addr, dialer)
+		role, err := pgclient.NodeRole(ctx)
+		if err != nil {
+			return "", fmt.Errorf("can't get role for %s: %w", addr, err)
+		}
+
+		if role == "leader" {
+			return addr, nil
+		}
+	}
+	return "", fmt.Errorf("no instances found with leader role")
+}
+
 func machineRole(machine *api.Machine) (role string) {
 	role = "unknown"
 
@@ -177,3 +193,12 @@ func machineRole(machine *api.Machine) (role string) {
 	}
 	return role
 }
+
+func pickLeader(ctx context.Context, machines []*api.Machine) (*api.Machine, error) {
+	for _, machine := range machines {
+		if machineRole(machine) == "leader" {
+			return machine, nil
+		}
+	}
+	return nil, fmt.Errorf("No active leader")
+}
